@@ -15,6 +15,8 @@ python easier.
 
 
 import sys
+import pprint
+# import PrettyTable
 
 
 def error (message, status=0):
